
def zhangjie():
    print('hello')

def hello():
    print('zhangjie')
